use nom::bytes::complete::tag_no_case;
use nom::character::complete::anychar;
use nom::combinator::map;
use nom::multi::many_till;

use super::keyword::filtered_keyword;
use super::OrgSource;
use crate::error::Res;

#[cfg_attr(feature = "tracing", tracing::instrument(ret, level = "debug"))]
pub fn scan_for_setup_file<'s>(input: OrgSource<'s>) -> Res<OrgSource<'s>, &'s str> {
    let (remaining, setup) = map(
        many_till(anychar, filtered_keyword(setupfile_key)),
        |(_, kw)| kw.value,
    )(input)?;
    Ok((remaining, setup))
}

#[cfg_attr(feature = "tracing", tracing::instrument(ret, level = "debug"))]
fn setupfile_key<'s>(input: OrgSource<'s>) -> Res<OrgSource<'s>, OrgSource<'s>> {
    tag_no_case("setupfile")(input)
}
